@@ -26,6 +26,7 @@ struct {
 	{ "cache:",  "OAFIID:Bonobo_Moniker_Cache" },
 	{ "query:(", "OAFIID:Bonobo_Moniker_Query" },
 	{ "new:",    "OAFIID:Bonobo_Moniker_New"   },
+	{ "conf:",   "OAFIID:GNOME_Moniker_Config" },
 	{ NULL, NULL }
 };
 
@@ -75,7 +76,6 @@ bonobo_moniker_util_parse_name (const char *name, int *plen)
 				i--;
 			}
 			
-			printf ("FOUND %s %s %d %d %d\n",name, rval, l ,i,c);
 			if (plen)
 				*plen = i + c + 1;
 
